# define required pulp platform version.
%global pulp_version 2.8.7

Name:      pulp-rpm
Version:   2.8.7
Release:   1%{?dist}
BuildArch: noarch

License:   GPLv2+
Summary:   Support for RPM content in the Pulp platform
URL:       https://github.com/pulp/pulp_rpm
Source0:   https://github.com/pulp/pulp_rpm/archive/%{name}-%{version}-1.tar.gz

BuildRequires:  python-rpm-macros
BuildRequires:  python2-rpm-macros
BuildRequires:  python2-devel
BuildRequires:  python2-setuptools
BuildRequires:  python2-sphinx


%description
Provides a collection of platform plugins, client extensions and agent
handlers that provide RPM support.


%prep
%autosetup -n pulp_rpm-%{name}-%{version}-1


%build
for directory in $(find . -type f -name "setup.py" | xargs dirname)
do
    pushd $directory
    %py2_build
    popd
done

pushd docs
make %{?_smp_mflags} html
# We don't want to install the objects.inv, because it is a build-time database
rm _build/html/objects.inv
popd


%install
for directory in $(find . -type f -name "setup.py" | xargs dirname)
do
    pushd $directory
    %py2_install
    popd
done

install -d %{buildroot}/%{_sysconfdir}/httpd/conf.d
install -d %{buildroot}/%{_sysconfdir}/pki/pulp/content
install -d %{buildroot}/%{_sysconfdir}/pulp/agent/conf.d
install -d %{buildroot}/%{_sysconfdir}/pulp/vhosts80
install -d %{buildroot}/%{_sysconfdir}/yum/pluginconf.d
install -d %{buildroot}/%{_sysconfdir}/yum.repos.d
install -d %{buildroot}/%{_usr}/lib/pulp/admin/extensions
install -d %{buildroot}/%{_usr}/lib/pulp/agent/handlers
install -d %{buildroot}/%{_usr}/lib/pulp/consumer/extensions
install -d %{buildroot}/%{_usr}/lib/pulp/plugins
install -d %{buildroot}/%{_usr}/lib/yum-plugins
install -d %{buildroot}/%{_var}/lib/pulp/published/yum/http
install -d %{buildroot}/%{_datadir}/pulp-rpm
install -d %{buildroot}/%{_var}/lib/pulp/published/yum/https

install -pm644 handlers/etc/pulp/agent/conf.d/* %{buildroot}/%{_sysconfdir}/pulp/agent/conf.d/
install -pm644 handlers/etc/yum/pluginconf.d/pulp-profile-update.conf \
    %{buildroot}/%{_sysconfdir}/yum/pluginconf.d/
install -pm644 plugins/etc/httpd/conf.d/pulp_rpm.conf %{buildroot}/%{_sysconfdir}/httpd/conf.d/
install -pm644 plugins/etc/pulp/vhosts80/rpm.conf %{buildroot}/%{_sysconfdir}/pulp/vhosts80/
install -pm644 handlers/usr/lib/yum-plugins/* %{buildroot}/%{_usr}/lib/yum-plugins/
install -pm644 plugins/usr/share/pulp-rpm/pulp_distribution.xsd %{buildroot}/%{_datadir}/pulp-rpm

# Ghost repository file for consumers
touch %{buildroot}/%{_sysconfdir}/yum.repos.d/pulp.repo


# ---- Admin Extensions --------------------------------------------------------
%package admin-extensions
Summary: The RPM admin client extensions
Requires: pulp-admin-client = %{pulp_version}
Requires: python-pulp-rpm-common = %{version}


%description admin-extensions
A collection of extensions that supplement and override generic admin
client capabilities with RPM specific features.


%files admin-extensions
%license COPYRIGHT LICENSE
%doc AUTHORS
%{python_sitelib}/pulp_rpm/extensions/admin/
%{python_sitelib}/pulp_rpm_extensions_admin*.egg-info


# ---- Consumer Extensions -----------------------------------------------------
%package consumer-extensions
Summary: The RPM consumer client extensions
Requires: pulp-consumer-client = %{pulp_version}
Requires: python-pulp-rpm-common = %{version}


%description consumer-extensions
A collection of extensions that supplement and override generic consumer
client capabilities with RPM specific features.


%files consumer-extensions
%license COPYRIGHT LICENSE
%doc AUTHORS
%{python_sitelib}/pulp_rpm/extensions/consumer/
%{python_sitelib}/pulp_rpm_extensions_consumer*.egg-info


# ---- Development package -----------------------------------------------------
%package devel
Summary: Pulp RPM devel package
Requires: python-pulp-rpm-common = %{version}


%description devel
A collection of development utilities useful for developing pulp-rpm.


%files devel
%license COPYRIGHT LICENSE
%doc AUTHORS
%{python_sitelib}/pulp_rpm/devel/
%{python_sitelib}/pulp_rpm_devel*.egg-info


# ---- Documentation ----------------------------------------------------------
%package doc 
Summary: Pulp RPM documentation


%description doc 
Documentation for the Pulp RPM plugins.


%files doc 
%license COPYRIGHT LICENSE
%doc AUTHORS
%doc docs/_build/html/*


# ---- Agent Handlers ----------------------------------------------------------
%package handlers
Summary: Pulp agent rpm handlers
Requires: fedora-repos
Requires: python-rhsm
Requires: python-pulp-agent-lib = %{pulp_version}
Requires: python-pulp-rpm-common = %{version}


%description handlers
A collection of handlers that provide both Linux and RPM specific
functionality within the Pulp agent.  This includes RPM install, update,
uninstall; RPM profile reporting; binding through yum repository
management and Linux specific commands such as system reboot.


%files handlers
%license COPYRIGHT LICENSE
%doc AUTHORS
%{_sysconfdir}/pulp/agent/conf.d/bind.conf
%{_sysconfdir}/pulp/agent/conf.d/linux.conf
%{_sysconfdir}/pulp/agent/conf.d/rpm.conf
%ghost %{_sysconfdir}/yum.repos.d/pulp.repo
%{python_sitelib}/pulp_rpm/handlers/
%{python_sitelib}/pulp_rpm_handlers*.egg-info


# ---- Plugins -----------------------------------------------------------------
%package plugins
Summary: Pulp RPM plugins
Requires: createrepo >= 0.9.9-21
Requires: createrepo_c >= 0.4.1-1
Requires: genisoimage
Requires: m2crypto
Requires: pulp-server = %{pulp_version}
Requires: pyliblzma
Requires: python-lxml
Requires: python-nectar >= 1.2.1
Requires: python-rhsm >= 1.8.0
Requires: python2-pulp-oid_validation >= 2.7.0
Requires: python2-pulp-rpm-common = %{pulp_version}


%description plugins
Provides a collection of platform plugins that extend the Pulp platform
to provide RPM specific support.


%files plugins
%license COPYRIGHT LICENSE
%doc AUTHORS
%config(noreplace) %{_sysconfdir}/httpd/conf.d/pulp_rpm.conf
%attr(-, apache, apache) %{_sysconfdir}/pki/pulp/content/
%{_sysconfdir}/pulp/vhosts80/rpm.conf
%{python_sitelib}/pulp_rpm/plugins/
%{python_sitelib}/pulp_rpm/yum_plugin/
%{python_sitelib}/pulp_rpm_plugins*.egg-info
%{_usr}/share/pulp-rpm/
%attr(-, apache, apache) %{_var}/lib/pulp/published/yum/


# ---- YUM Plugins -------------------------------------------------------------
%package yumplugins
Summary: Yum plugins supplementing in Pulp consumer operations
Requires: python-rhsm >= 1.8.0
Requires: python2-pulp-bindings = %{pulp_version}
Requires: yum


%description yumplugins
A collection of yum plugins supplementing Pulp consumer operations.


%files yumplugins
%license COPYRIGHT LICENSE
%doc AUTHORS
%{_sysconfdir}/yum/pluginconf.d/pulp-profile-update.conf
%{_usr}/lib/yum-plugins/pulp-profile-update.py*


# ---- RPM Common --------------------------------------------------------------
%package -n python2-pulp-rpm-common
Summary: Pulp RPM support common library
Group: Development/Languages
Requires: python-pulp-common = %{pulp_version}
%{?python_provide:%python_provide python2-pulp-rpm-common}


%description -n python2-pulp-rpm-common
A collection of modules shared among all RPM components.


%files -n python2-pulp-rpm-common
%license COPYRIGHT LICENSE
%doc AUTHORS
%dir %{python_sitelib}/pulp_rpm
%{python_sitelib}/pulp_rpm/__init__.py*
%{python_sitelib}/pulp_rpm/common/
%dir %{python_sitelib}/pulp_rpm/extensions/
%{python_sitelib}/pulp_rpm/extensions/__init__.py*
%{python_sitelib}/pulp_rpm_common*.egg-info


%changelog
* Fri Aug 19 2016 Jeremy Cline <jcline@redhat.com> - 2.8.7-1
- Update to 2.8.7

* Mon Aug 08 2016 Jeremy Cline <jcline@redhat.com> - 2.8.6-2
- Bump required platform version to 2.8.6.

* Mon Jul 18 2016 Jeremy Cline <jcline@redhat.com> - 2.8.6-1
- Update to 2.8.6

* Thu Jul 14 2016 Jeremy Cline <jcline@redhat.com> - 2.8.5-1
- Update to 2.8.5

* Tue May 17 2016 Randy Barlow <rbarlow@redhat.com> - 2.8.3-1
- Update to 2.8.3 (#1337312).
- Change the license to GPLv2+ as per the COPYRIGHT file.
- Include the AUTHORS file as documentation on all subpackages.

* Fri Mar 18 2016 Randy Barlow <rbarlow@redhat.com> - 2.8.0-1
- Update to 2.8.0.

* Wed Mar 09 2016 Randy Barlow <rbarlow@redhat.com> - 2.8.0-0.9.rc.1
- Update to the 2.8.0 release candidate.

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.8.0-0.4.beta.1.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jan 29 2016 Randy Barlow <rbarlow@redhat.com> - 2.8.0-0.4.beta.1
- Initial release.
